@@ -2,6 +2,7 @@ from __future__ import absolute_import, print_function, division
 
 from pyramid_frontend.theme import Theme
 from pyramid_frontend.images.chain import FilterChain
+from pyramid_frontend.assets.less import LessAsset
 
 
 def base_includeme(config):
@@ -15,7 +16,7 @@ class BaseTheme(Theme):
         FilterChain('full', width=400, height=400, crop=True),
     ]
     assets = {
-        'main-less': ('/_base/css/main.less', 'less'),
+        'main-less': LessAsset('/_base/css/main.less'),
     }
     includes = [
         base_includeme,
